@@ -5,8 +5,10 @@ prefix=/usr
 incdir=${prefix}/include
 libdir=${prefix}/lib
 
-LINKHEADERS="ncurses.h curses.h form.h menu.h panel.h unctrl.h \
- ncurses_dll.h eti.h term.h"
+(cd ${incdir}/ncurses;
+  ln -fs curses.h ncurses.h
+)
+LINKHEADERS="ncurses.h curses.h form.h menu.h panel.h unctrl.h ncurses_dll.h"
 for fn in ${LINKHEADERS}; do
   (cd ${incdir}; rm -f ${fn} ; ln -s ncurses/${fn} ${fn} )
 done
@@ -17,7 +19,3 @@ done
   rm -f terminfo        ; ln -fs ../share/terminfo terminfo ;
 )
 
-(cd ${incdir}/ncurses;
-  ln -fs curses.h ncurses.h
-)
-  
